To do — ASE documentation

### Navigation

- index
- modules |
- ASE development »

# To do

Check our issue tracker.

## Documentation

- Put example of Verlet dynamics in ase/md
- talk about writing files - pos, py and pckl
- Write more about the parameters of the supported elements of the EMT calculator.

## Code

- Could the directions argument of ase.lattice.FaceCenteredCubic etc. have default values?

### Navigation

- index
- modules |
- ASE development »